@@ -162,8 +162,8 @@ impl<T> LinkedListAsync<T> {
         #[cfg(feature = "for_futures")]
         {
             {
-                let alive = { self.alive.lock().unwrap().load(Ordering::SeqCst) };
-                if alive {
+                let alive = self.alive.lock().unwrap();
+                if alive.load(Ordering::SeqCst) {
                     self.inner.lock().unwrap().push_back(input);
                 }
 
@@ -186,7 +186,8 @@ impl<T> LinkedListAsync<T> {
     #[cfg(feature = "for_futures")]
     #[inline]
     fn wake(&self) {
-        if let Some(waker) = self.waker.lock().unwrap().take() {
+        let mut waker = self.waker.lock().unwrap();
+        if let Some(waker) = waker.take() {
             waker.wake();
         }
     }
@@ -215,7 +216,7 @@ where
     type Item = T;
 
     fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
-        let mut inner = self.inner.lock().unwrap();
+        // let mut inner = self.inner.lock().unwrap();
         let alive = self.alive.lock().unwrap();
         let mut waker = self.waker.lock().unwrap();
 
@@ -223,7 +224,7 @@ where
         // {
         //     picked = self.pop_front();
         // }
-        picked = inner.pop_front();
+        picked = self.pop_front();
         if picked.is_some() {
             return Poll::Ready(picked);
         }
@@ -235,22 +236,22 @@ where
             // picked = inner.pop_front();
 
             // Check Pending(None) or Ready(Some(item))
-            if picked.is_none() {
-                // Keep Pending
-                {
-                    waker.replace(cx.waker().clone());
-                };
-                return Poll::Pending;
-            }
-            return Poll::Ready(picked);
+            // if picked.is_none() {
+            // Keep Pending
+            {
+                waker.replace(cx.waker().clone());
+            };
+            return Poll::Pending;
+            // }
+            // return Poll::Ready(picked);
         }
         return Poll::Ready(None);
     }
 
     fn size_hint(&self) -> (usize, Option<usize>) {
         // Check alive
-        let alive = { self.alive.lock().unwrap().load(Ordering::SeqCst) };
-        if alive {
+        let alive = self.alive.lock().unwrap();
+        if alive.load(Ordering::SeqCst) {
             return (0, Some(0));
         }
         return (0, None);
